==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/oracle/dcoracle/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("DCOracle2 OCI Driver")
url = "http://www.zope.org/Members/matt/dco2/"
doc = """
Description
-----------
An Oracle driver from Digital Creations (Zope).  Works with Oracle
7.3, 8.x, 9i via Oracle's SQL-Net OCI interface.

The "Oracle Database Bindings for Python" are packaged with the
"Zope Oracle Database Adapter". GNUe does not use the Zope
Adapter, so you can safely ignore any installation instructions
referring to Zope.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP (Installer available)

Connection Properties
----------------------
* service  -- This is the Oracle TNS connection name

Examples
--------
provider=oracle         # Use the DCOracle2 adapter
service=mytnsname       # The TNS connection string of the database

Notes
-----
1. Requires Oracle Client Libraries.

2. Does not recognize the TWO_TASK environment setting.

"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/oracle/dcoracle/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("DCOracle2 OCI Driver")
url = "http://www.zope.org/Members/matt/dco2/"
doc = """
Description
-----------
An Oracle driver from Digital Creations (Zope).  Works with Oracle
7.3, 8.x, 9i via Oracle's SQL-Net OCI interface.

The "Oracle Database Bindings for Python" are packaged with the
"Zope Oracle Database Adapter". GNUe does not use the Zope
Adapter, so you can safely ignore any installation instructions
referring to Zope.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP (Installer available)

Connection Properties
----------------------
* service  -- This is the Oracle TNS connection name

Examples
--------
provider=oracle         # Use the DCOracle2 adapter
service=mytnsname       # The TNS connection string of the database

Notes
-----
1. Requires Oracle Client Libraries.

2. Does not recognize the TWO_TASK environment setting.

3. Creation of new databases with "gnue-schema --createdb" does not
   work with this driver. Index introspection is not supported

4. Other than that, the driver is fully functional with no known serious
   problems.
"""
